@@ -14,10 +14,10 @@ t_SRT_Terse;
 ######################################################################
 
 sub create_and_populate_model {
-	my (undef, $class) = @_;
+	my (undef, $class, $auto_ass_def_con) = @_;
 
 	my $model = $class->new_container();
-	$model->auto_assert_deferrable_constraints( 1 );
+	$model->auto_assert_deferrable_constraints( $auto_ass_def_con ); # undefined arg means faster performance
 
 	##### NEXT SET CATALOG ELEMENT-TYPE DETAILS #####
 
@@ -449,15 +449,12 @@ sub create_and_populate_model {
 
 	##### END OF DETAILS SETTING #####
 
-	# Now check that we didn't omit something important:
-	$model->assert_deferrable_constraints();
-
 	return( $model );
 }
 
 ######################################################################
 
-sub expected_model_xml_output {
+sub expected_model_nid_xml_output {
 	return(
 '<?xml version="1.0" encoding="UTF-8"?>
 <root>
@@ -775,4 +772,322 @@ sub expected_model_xml_output {
 
 ######################################################################
 
+sub expected_model_sid_xml_output {
+	return(
+'<?xml version="1.0" encoding="UTF-8"?>
+<root>
+	<elements>
+		<scalar_data_type id="1" si_name="bin1k" base_type="STR_BIT" max_octets="1000" />
+		<scalar_data_type id="2" si_name="bin32k" base_type="STR_BIT" max_octets="32000" />
+		<scalar_data_type id="3" si_name="str4" base_type="STR_CHAR" max_chars="4" store_fixed="1" char_enc="ASCII" trim_white="1" uc_latin="1" pad_char=" " trim_pad="1" />
+		<scalar_data_type id="4" si_name="str10" base_type="STR_CHAR" max_chars="10" store_fixed="1" char_enc="ASCII" trim_white="1" pad_char=" " trim_pad="1" />
+		<scalar_data_type id="5" si_name="str30" base_type="STR_CHAR" max_chars="30" char_enc="ASCII" trim_white="1" />
+		<scalar_data_type id="6" si_name="str2k" base_type="STR_CHAR" max_chars="2000" char_enc="UTF8" />
+		<scalar_data_type id="7" si_name="byte" base_type="NUM_INT" num_precision="3" />
+		<scalar_data_type id="8" si_name="short" base_type="NUM_INT" num_precision="5" />
+		<scalar_data_type id="9" si_name="int" base_type="NUM_INT" num_precision="10" />
+		<scalar_data_type id="10" si_name="long" base_type="NUM_INT" num_precision="19" />
+		<scalar_data_type id="11" si_name="ubyte" base_type="NUM_INT" num_precision="3" num_unsigned="1" />
+		<scalar_data_type id="12" si_name="ushort" base_type="NUM_INT" num_precision="5" num_unsigned="1" />
+		<scalar_data_type id="13" si_name="uint" base_type="NUM_INT" num_precision="10" num_unsigned="1" />
+		<scalar_data_type id="14" si_name="ulong" base_type="NUM_INT" num_precision="19" num_unsigned="1" />
+		<scalar_data_type id="15" si_name="float" base_type="NUM_APR" num_octets="4" />
+		<scalar_data_type id="16" si_name="double" base_type="NUM_APR" num_octets="8" />
+		<scalar_data_type id="17" si_name="dec10p2" base_type="NUM_EXA" num_precision="10" num_scale="2" />
+		<scalar_data_type id="18" si_name="dec255" base_type="NUM_EXA" num_precision="255" />
+		<scalar_data_type id="19" si_name="boolean" base_type="BOOLEAN" />
+		<scalar_data_type id="20" si_name="datetime" base_type="DATM_FULL" calendar="ABS" />
+		<scalar_data_type id="21" si_name="dtchines" base_type="DATM_FULL" calendar="CHI" />
+		<scalar_data_type id="22" si_name="sex" base_type="STR_CHAR" max_chars="1" char_enc="ASCII">
+			<scalar_data_type_opt id="28" si_value="M" />
+			<scalar_data_type_opt id="29" si_value="F" />
+		</scalar_data_type>
+		<scalar_data_type id="23" si_name="str20" base_type="STR_CHAR" max_chars="20" char_enc="ASCII" />
+		<scalar_data_type id="24" si_name="str100" base_type="STR_CHAR" max_chars="100" char_enc="ASCII" />
+		<scalar_data_type id="25" si_name="str250" base_type="STR_CHAR" max_chars="250" char_enc="ASCII" />
+		<scalar_data_type id="26" si_name="entitynm" base_type="STR_CHAR" max_chars="30" char_enc="ASCII" />
+		<scalar_data_type id="27" si_name="generic" base_type="STR_CHAR" max_chars="250" char_enc="ASCII" />
+		<row_data_type id="304" si_name="person">
+			<row_data_type_field id="220" si_name="person_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="221" si_name="alternate_id" scalar_data_type="[,root,elements,str20]" />
+			<row_data_type_field id="222" si_name="name" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="223" si_name="sex" scalar_data_type="[,root,elements,sex]" />
+			<row_data_type_field id="224" si_name="father_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="225" si_name="mother_id" scalar_data_type="[,root,elements,int]" />
+		</row_data_type>
+		<row_data_type id="312" si_name="person_with_parents">
+			<row_data_type_field id="116" si_name="self_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="117" si_name="self_name" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="118" si_name="father_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="119" si_name="father_name" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="120" si_name="mother_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="121" si_name="mother_name" scalar_data_type="[,root,elements,str100]" />
+		</row_data_type>
+		<row_data_type id="301" si_name="user_auth">
+			<row_data_type_field id="201" si_name="user_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="202" si_name="login_name" scalar_data_type="[,root,elements,str20]" />
+			<row_data_type_field id="203" si_name="login_pass" scalar_data_type="[,root,elements,str20]" />
+			<row_data_type_field id="204" si_name="private_name" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="205" si_name="private_email" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="206" si_name="may_login" scalar_data_type="[,root,elements,boolean]" />
+			<row_data_type_field id="207" si_name="max_sessions" scalar_data_type="[,root,elements,byte]" />
+		</row_data_type>
+		<row_data_type id="302" si_name="user_profile">
+			<row_data_type_field id="208" si_name="user_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="209" si_name="public_name" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="210" si_name="public_email" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="211" si_name="web_url" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="212" si_name="contact_net" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="213" si_name="contact_phy" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="214" si_name="bio" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="215" si_name="plan" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="216" si_name="comments" scalar_data_type="[,root,elements,str250]" />
+		</row_data_type>
+		<row_data_type id="311" si_name="user">
+			<row_data_type_field id="101" si_name="user_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="102" si_name="login_name" scalar_data_type="[,root,elements,str20]" />
+			<row_data_type_field id="103" si_name="login_pass" scalar_data_type="[,root,elements,str20]" />
+			<row_data_type_field id="104" si_name="private_name" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="105" si_name="private_email" scalar_data_type="[,root,elements,str100]" />
+			<row_data_type_field id="106" si_name="may_login" scalar_data_type="[,root,elements,boolean]" />
+			<row_data_type_field id="107" si_name="max_sessions" scalar_data_type="[,root,elements,byte]" />
+			<row_data_type_field id="108" si_name="public_name" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="109" si_name="public_email" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="110" si_name="web_url" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="111" si_name="contact_net" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="112" si_name="contact_phy" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="113" si_name="bio" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="114" si_name="plan" scalar_data_type="[,root,elements,str250]" />
+			<row_data_type_field id="115" si_name="comments" scalar_data_type="[,root,elements,str250]" />
+		</row_data_type>
+		<row_data_type id="303" si_name="user_pref">
+			<row_data_type_field id="217" si_name="user_id" scalar_data_type="[,root,elements,int]" />
+			<row_data_type_field id="218" si_name="pref_name" scalar_data_type="[,root,elements,entitynm]" />
+			<row_data_type_field id="219" si_name="pref_value" scalar_data_type="[,root,elements,generic]" />
+		</row_data_type>
+		<row_data_type id="313" si_name="user_theme">
+			<row_data_type_field id="122" si_name="theme_name" scalar_data_type="[,root,elements,generic]" />
+			<row_data_type_field id="123" si_name="theme_count" scalar_data_type="[,root,elements,int]" />
+		</row_data_type>
+	</elements>
+	<blueprints>
+		<catalog id="31" si_name="The Catalog Blueprint">
+			<owner id="32" si_name="Gene\'s Owner" />
+			<schema id="33" si_name="gene" owner="[,root,blueprints,The Catalog Blueprint,Gene\'s Owner]">
+				<table id="44" si_name="person" row_data_type="[,root,elements,person]">
+					<table_field id="520" si_row_field="[,root,elements,person,person_id]" mandatory="1" default_val="1" auto_inc="1" />
+					<table_field id="522" si_row_field="[,root,elements,person,name]" mandatory="1" />
+					<table_index id="701" si_name="primary" index_type="UNIQUE">
+						<table_index_field id="702" si_field="[,root,elements,person,person_id]" />
+					</table_index>
+					<table_index id="703" si_name="ak_alternate_id" index_type="UNIQUE">
+						<table_index_field id="704" si_field="[,root,elements,person,alternate_id]" />
+					</table_index>
+					<table_index id="705" si_name="fk_father" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<table_index_field id="706" si_field="[,root,elements,person,father_id]" f_field="[,root,elements,person,person_id]" />
+					</table_index>
+					<table_index id="707" si_name="fk_mother" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<table_index_field id="708" si_field="[,root,elements,person,mother_id]" f_field="[,root,elements,person,person_id]" />
+					</table_index>
+				</table>
+				<view id="52" si_name="person_with_parents" view_type="JOINED" row_data_type="[,root,elements,person_with_parents]">
+					<view_src id="73" si_name="self" match="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<view_src_field id="417" si_match_field="[,root,elements,person,person_id]" />
+						<view_src_field id="418" si_match_field="[,root,elements,person,name]" />
+						<view_src_field id="425" si_match_field="[,root,elements,person,father_id]" />
+						<view_src_field id="426" si_match_field="[,root,elements,person,mother_id]" />
+					</view_src>
+					<view_src id="74" si_name="father" match="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<view_src_field id="419" si_match_field="[,root,elements,person,person_id]" />
+						<view_src_field id="420" si_match_field="[,root,elements,person,name]" />
+					</view_src>
+					<view_src id="75" si_name="mother" match="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<view_src_field id="421" si_match_field="[,root,elements,person,person_id]" />
+						<view_src_field id="422" si_match_field="[,root,elements,person,name]" />
+					</view_src>
+					<view_field id="616" si_row_field="[,root,elements,person_with_parents,self_id]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self,person_id]" />
+					<view_field id="617" si_row_field="[,root,elements,person_with_parents,self_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self,name]" />
+					<view_field id="618" si_row_field="[,root,elements,person_with_parents,father_id]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,father,person_id]" />
+					<view_field id="619" si_row_field="[,root,elements,person_with_parents,father_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,father,name]" />
+					<view_field id="620" si_row_field="[,root,elements,person_with_parents,mother_id]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,mother,person_id]" />
+					<view_field id="621" si_row_field="[,root,elements,person_with_parents,mother_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,mother,name]" />
+					<view_join id="731" lhs_src="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self]" rhs_src="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,father]" join_op="LEFT">
+						<view_join_field id="732" lhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self,father_id]" rhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,father,person_id]" />
+					</view_join>
+					<view_join id="733" lhs_src="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self]" rhs_src="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,mother]" join_op="LEFT">
+						<view_join_field id="734" lhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,self,mother_id]" rhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents,mother,person_id]" />
+					</view_join>
+				</view>
+				<table id="41" si_name="user_auth" row_data_type="[,root,elements,user_auth]">
+					<table_field id="501" si_row_field="[,root,elements,user_auth,user_id]" mandatory="1" default_val="1" auto_inc="1" />
+					<table_field id="502" si_row_field="[,root,elements,user_auth,login_name]" mandatory="1" />
+					<table_field id="503" si_row_field="[,root,elements,user_auth,login_pass]" mandatory="1" />
+					<table_field id="504" si_row_field="[,root,elements,user_auth,private_name]" mandatory="1" />
+					<table_field id="505" si_row_field="[,root,elements,user_auth,private_email]" mandatory="1" />
+					<table_field id="506" si_row_field="[,root,elements,user_auth,may_login]" mandatory="1" />
+					<table_field id="507" si_row_field="[,root,elements,user_auth,max_sessions]" mandatory="1" default_val="3" />
+					<table_index id="709" si_name="primary" index_type="UNIQUE">
+						<table_index_field id="710" si_field="[,root,elements,user_auth,user_id]" />
+					</table_index>
+					<table_index id="711" si_name="ak_login_name" index_type="UNIQUE">
+						<table_index_field id="712" si_field="[,root,elements,user_auth,login_name]" />
+					</table_index>
+					<table_index id="713" si_name="ak_private_email" index_type="UNIQUE">
+						<table_index_field id="714" si_field="[,root,elements,user_auth,private_email]" />
+					</table_index>
+				</table>
+				<table id="42" si_name="user_profile" row_data_type="[,root,elements,user_profile]">
+					<table_field id="508" si_row_field="[,root,elements,user_profile,user_id]" mandatory="1" />
+					<table_field id="509" si_row_field="[,root,elements,user_profile,public_name]" mandatory="1" />
+					<table_index id="715" si_name="primary" index_type="UNIQUE">
+						<table_index_field id="716" si_field="[,root,elements,user_profile,user_id]" />
+					</table_index>
+					<table_index id="717" si_name="ak_public_name" index_type="UNIQUE">
+						<table_index_field id="718" si_field="[,root,elements,user_profile,public_name]" />
+					</table_index>
+					<table_index id="719" si_name="fk_user" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,user_auth]">
+						<table_index_field id="720" si_field="[,root,elements,user_profile,user_id]" f_field="[,root,elements,user_auth,user_id]" />
+					</table_index>
+				</table>
+				<view id="51" si_name="user" view_type="JOINED" row_data_type="[,root,elements,user]">
+					<view_src id="71" si_name="user_auth" match="[,root,blueprints,The Catalog Blueprint,gene,user_auth]">
+						<view_src_field id="401" si_match_field="[,root,elements,user_auth,user_id]" />
+						<view_src_field id="402" si_match_field="[,root,elements,user_auth,login_name]" />
+						<view_src_field id="403" si_match_field="[,root,elements,user_auth,login_pass]" />
+						<view_src_field id="404" si_match_field="[,root,elements,user_auth,private_name]" />
+						<view_src_field id="405" si_match_field="[,root,elements,user_auth,private_email]" />
+						<view_src_field id="406" si_match_field="[,root,elements,user_auth,may_login]" />
+						<view_src_field id="407" si_match_field="[,root,elements,user_auth,max_sessions]" />
+					</view_src>
+					<view_src id="72" si_name="user_profile" match="[,root,blueprints,The Catalog Blueprint,gene,user_profile]">
+						<view_src_field id="408" si_match_field="[,root,elements,user_profile,user_id]" />
+						<view_src_field id="409" si_match_field="[,root,elements,user_profile,public_name]" />
+						<view_src_field id="410" si_match_field="[,root,elements,user_profile,public_email]" />
+						<view_src_field id="411" si_match_field="[,root,elements,user_profile,web_url]" />
+						<view_src_field id="412" si_match_field="[,root,elements,user_profile,contact_net]" />
+						<view_src_field id="413" si_match_field="[,root,elements,user_profile,contact_phy]" />
+						<view_src_field id="414" si_match_field="[,root,elements,user_profile,bio]" />
+						<view_src_field id="415" si_match_field="[,root,elements,user_profile,plan]" />
+						<view_src_field id="416" si_match_field="[,root,elements,user_profile,comments]" />
+					</view_src>
+					<view_field id="601" si_row_field="[,root,elements,user,user_id]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,user_id]" />
+					<view_field id="602" si_row_field="[,root,elements,user,login_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,login_name]" />
+					<view_field id="603" si_row_field="[,root,elements,user,login_pass]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,login_pass]" />
+					<view_field id="604" si_row_field="[,root,elements,user,private_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,private_name]" />
+					<view_field id="605" si_row_field="[,root,elements,user,private_email]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,private_email]" />
+					<view_field id="606" si_row_field="[,root,elements,user,may_login]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,may_login]" />
+					<view_field id="607" si_row_field="[,root,elements,user,max_sessions]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,max_sessions]" />
+					<view_field id="608" si_row_field="[,root,elements,user,public_name]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,public_name]" />
+					<view_field id="609" si_row_field="[,root,elements,user,public_email]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,public_email]" />
+					<view_field id="610" si_row_field="[,root,elements,user,web_url]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,web_url]" />
+					<view_field id="611" si_row_field="[,root,elements,user,contact_net]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,contact_net]" />
+					<view_field id="612" si_row_field="[,root,elements,user,contact_phy]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,contact_phy]" />
+					<view_field id="613" si_row_field="[,root,elements,user,bio]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,bio]" />
+					<view_field id="614" si_row_field="[,root,elements,user,plan]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,plan]" />
+					<view_field id="615" si_row_field="[,root,elements,user,comments]" src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,comments]" />
+					<view_join id="735" lhs_src="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth]" rhs_src="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile]" join_op="LEFT">
+						<view_join_field id="736" lhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_auth,user_id]" rhs_src_field="[,root,blueprints,The Catalog Blueprint,gene,user,user_profile,user_id]" />
+					</view_join>
+				</view>
+				<table id="43" si_name="user_pref" row_data_type="[,root,elements,user_pref]">
+					<table_field id="517" si_row_field="[,root,elements,user_pref,user_id]" mandatory="1" />
+					<table_field id="518" si_row_field="[,root,elements,user_pref,pref_name]" mandatory="1" />
+					<table_index id="721" si_name="primary" index_type="UNIQUE">
+						<table_index_field id="722" si_field="[,root,elements,user_pref,user_id]" />
+						<table_index_field id="723" si_field="[,root,elements,user_pref,pref_name]" />
+					</table_index>
+					<table_index id="724" si_name="fk_user" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,user_auth]">
+						<table_index_field id="725" si_field="[,root,elements,user_pref,user_id]" f_field="[,root,elements,user_auth,user_id]" />
+					</table_index>
+				</table>
+			</schema>
+		</catalog>
+		<application id="34" si_name="My App">
+			<view id="53" si_name="user_theme" view_type="JOINED" row_data_type="[,root,elements,user_theme]">
+				<view_src id="76" si_name="user_pref" match="[,root,blueprints,The Catalog Blueprint,gene,user_pref]">
+					<view_src_field id="423" si_match_field="[,root,elements,user_pref,pref_name]" />
+					<view_src_field id="424" si_match_field="[,root,elements,user_pref,pref_value]" />
+				</view_src>
+				<view_field id="842" si_row_field="[,root,elements,user_theme,theme_name]" src_field="[,root,blueprints,My App,user_theme,user_pref,pref_value]" />
+				<view_expr id="843" view_part="RESULT" set_result_field="[,root,elements,user_theme,theme_count]" cont_type="SCALAR" valf_call_sroutine="COUNT">
+					<view_expr id="844" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,user_theme,user_pref,pref_value]" />
+				</view_expr>
+				<view_expr id="811" view_part="WHERE" cont_type="SCALAR" valf_call_sroutine="EQ">
+					<view_expr id="812" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,user_theme,user_pref,pref_name]" />
+					<view_expr id="813" cont_type="SCALAR" valf_literal="theme" scalar_data_type="[,root,elements,str30]" />
+				</view_expr>
+				<view_expr id="814" view_part="GROUP" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,user_theme,user_pref,pref_value]" />
+				<view_expr id="815" view_part="HAVING" cont_type="SCALAR" valf_call_sroutine="GT">
+					<view_expr id="816" cont_type="SCALAR" valf_call_sroutine="COUNT" />
+					<view_expr id="817" cont_type="SCALAR" valf_literal="1" scalar_data_type="[,root,elements,int]" />
+				</view_expr>
+				<view_expr id="855" view_part="ORDER" cont_type="SCALAR" valf_result_field="[,root,elements,user_theme,theme_count]" />
+				<view_expr id="856" view_part="ORDER" cont_type="SCALAR" valf_result_field="[,root,elements,user_theme,theme_name]" />
+			</view>
+			<routine id="61" si_name="get_user" routine_type="FUNCTION" return_cont_type="CURSOR">
+				<routine_arg id="91" si_name="curr_uid" cont_type="SCALAR" scalar_data_type="[,root,elements,int]" />
+				<view id="55" si_name="get_user" view_type="JOINED" row_data_type="[,root,elements,user]">
+					<view_src id="78" si_name="m" match="[,root,blueprints,The Catalog Blueprint,gene,user]">
+						<view_src_field id="430" si_match_field="[,root,elements,user,user_id]" />
+						<view_src_field id="431" si_match_field="[,root,elements,user,login_name]" />
+					</view_src>
+					<view_expr id="801" view_part="WHERE" cont_type="SCALAR" valf_call_sroutine="EQ">
+						<view_expr id="802" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_user,get_user,m,user_id]" />
+						<view_expr id="803" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,My App,get_user,curr_uid]" />
+					</view_expr>
+					<view_expr id="851" view_part="ORDER" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_user,get_user,m,login_name]" />
+				</view>
+				<routine_stmt id="94" call_sroutine="CURSOR_OPEN" />
+			</routine>
+			<routine id="62" si_name="get_pwp" routine_type="FUNCTION" return_cont_type="CURSOR">
+				<routine_arg id="92" si_name="srchw_fa" cont_type="SCALAR" scalar_data_type="[,root,elements,str30]" />
+				<routine_arg id="93" si_name="srchw_mo" cont_type="SCALAR" scalar_data_type="[,root,elements,str30]" />
+				<view id="56" si_name="get_pwp" view_type="JOINED" row_data_type="[,root,elements,person_with_parents]">
+					<view_src id="79" si_name="m" match="[,root,blueprints,The Catalog Blueprint,gene,person_with_parents]">
+						<view_src_field id="427" si_match_field="[,root,elements,person_with_parents,self_name]" />
+						<view_src_field id="428" si_match_field="[,root,elements,person_with_parents,father_name]" />
+						<view_src_field id="429" si_match_field="[,root,elements,person_with_parents,mother_name]" />
+					</view_src>
+					<view_expr id="804" view_part="WHERE" cont_type="SCALAR" valf_call_sroutine="AND">
+						<view_expr id="805" cont_type="SCALAR" valf_call_sroutine="LIKE">
+							<view_expr id="806" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_pwp,get_pwp,m,father_name]" />
+							<view_expr id="807" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,My App,get_pwp,srchw_fa]" />
+						</view_expr>
+						<view_expr id="808" cont_type="SCALAR" valf_call_sroutine="LIKE">
+							<view_expr id="809" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_pwp,get_pwp,m,mother_name]" />
+							<view_expr id="810" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,My App,get_pwp,srchw_mo]" />
+						</view_expr>
+					</view_expr>
+					<view_expr id="852" view_part="ORDER" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_pwp,get_pwp,m,self_name]" />
+					<view_expr id="853" view_part="ORDER" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_pwp,get_pwp,m,father_name]" />
+					<view_expr id="854" view_part="ORDER" cont_type="SCALAR" valf_src_field="[,root,blueprints,My App,get_pwp,get_pwp,m,mother_name]" />
+				</view>
+				<routine_stmt id="95" call_sroutine="CURSOR_OPEN" />
+			</routine>
+			<routine id="63" si_name="get_theme" routine_type="FUNCTION" return_cont_type="CURSOR">
+				<view id="57" si_name="get_theme" view_type="ALIAS" row_data_type="[,root,elements,user_theme]">
+					<view_src id="69" si_name="m" match="[,root,blueprints,My App,user_theme]" />
+				</view>
+				<routine_stmt id="96" call_sroutine="CURSOR_OPEN" />
+			</routine>
+			<routine id="64" si_name="get_person" routine_type="FUNCTION" return_cont_type="CURSOR">
+				<view id="54" si_name="get_person" view_type="ALIAS" row_data_type="[,root,elements,person]">
+					<view_src id="77" si_name="person" match="[,root,blueprints,The Catalog Blueprint,gene,person]" />
+				</view>
+				<routine_stmt id="97" call_sroutine="CURSOR_OPEN" />
+			</routine>
+		</application>
+	</blueprints>
+	<tools />
+	<sites>
+		<application_instance id="35" si_name="My App Instance" blueprint="[,root,blueprints,My App]" />
+	</sites>
+	<circumventions />
+</root>
+'
+	);
+}
+
+######################################################################
+
 1;
