@@ -555,15 +555,12 @@ sub create_and_populate_model {
 
 	##### END OF DETAILS SETTING #####
 
-	# Now check that we didn't omit something important:
-	$model->assert_deferrable_constraints();
-
 	return( $model );
 }
 
 ######################################################################
 
-sub expected_model_xml_output {
+sub expected_model_nid_xml_output {
 	return(
 '<?xml version="1.0" encoding="UTF-8"?>
 <root>
@@ -742,4 +739,183 @@ sub expected_model_xml_output {
 
 ######################################################################
 
+sub expected_model_sid_xml_output {
+	return(
+'<?xml version="1.0" encoding="UTF-8"?>
+<root>
+	<elements>
+		<scalar_data_type id="1" si_name="entity_id" base_type="NUM_INT" num_precision="9" />
+		<scalar_data_type id="2" si_name="person_name" base_type="STR_CHAR" max_chars="100" char_enc="UTF8" />
+		<row_data_type id="3" si_name="person">
+			<row_data_type_field id="4" si_name="person_id" scalar_data_type="[,root,elements,entity_id]" />
+			<row_data_type_field id="5" si_name="name" scalar_data_type="[,root,elements,person_name]" />
+			<row_data_type_field id="6" si_name="father_id" scalar_data_type="[,root,elements,entity_id]" />
+			<row_data_type_field id="7" si_name="mother_id" scalar_data_type="[,root,elements,entity_id]" />
+		</row_data_type>
+		<scalar_data_type id="8" si_name="boolean" base_type="BOOLEAN" />
+		<scalar_data_type id="9" si_name="loginauth" base_type="STR_CHAR" max_chars="20" char_enc="UTF8" />
+	</elements>
+	<blueprints>
+		<catalog id="10" si_name="The Catalog Blueprint">
+			<owner id="11" si_name="Gene\'s Owner" />
+			<schema id="12" si_name="gene" owner="[,root,blueprints,The Catalog Blueprint,Gene\'s Owner]">
+				<row_domain id="13" si_name="person_type" data_type="[,root,elements,person]" />
+				<table id="14" si_name="person" row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]">
+					<table_field id="15" si_row_field="[,root,elements,person,person_id]" mandatory="1" default_val="1" auto_inc="1" />
+					<table_field id="16" si_row_field="[,root,elements,person,name]" mandatory="1" />
+					<table_index id="17" si_name="primary" index_type="UNIQUE">
+						<table_index_field id="18" si_field="[,root,elements,person,person_id]" />
+					</table_index>
+					<table_index id="19" si_name="fk_father" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<table_index_field id="20" si_field="[,root,elements,person,father_id]" f_field="[,root,elements,person,person_id]" />
+					</table_index>
+					<table_index id="21" si_name="fk_mother" index_type="FOREIGN" f_table="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<table_index_field id="22" si_field="[,root,elements,person,mother_id]" f_field="[,root,elements,person,person_id]" />
+					</table_index>
+				</table>
+			</schema>
+		</catalog>
+		<application id="23" si_name="Setup">
+			<catalog_link id="24" si_name="admin_link" target="[,root,blueprints,The Catalog Blueprint]" />
+			<routine id="25" si_name="install_app_schema" routine_type="PROCEDURE">
+				<routine_stmt id="26" call_sroutine="CATALOG_CREATE">
+					<routine_expr id="27" call_sroutine_arg="LINK_BP" cont_type="SRT_NODE" act_on="[,root,blueprints,Setup,admin_link]" />
+					<routine_expr id="28" call_sroutine_arg="RECURSIVE" cont_type="SCALAR" valf_literal="1" scalar_data_type="[,root,elements,boolean]" />
+				</routine_stmt>
+			</routine>
+			<routine id="29" si_name="remove_app_schema" routine_type="PROCEDURE">
+				<routine_stmt id="30" call_sroutine="CATALOG_DELETE">
+					<routine_expr id="31" call_sroutine_arg="LINK_BP" cont_type="SRT_NODE" act_on="[,root,blueprints,Setup,admin_link]" />
+				</routine_stmt>
+			</routine>
+		</application>
+		<application id="32" si_name="People Watcher">
+			<catalog_link id="33" si_name="editor_link" target="[,root,blueprints,The Catalog Blueprint]" />
+			<routine id="34" si_name="declare_db_conn" routine_type="FUNCTION" return_cont_type="CONN">
+				<routine_var id="35" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_stmt id="36" call_sroutine="RETURN">
+					<routine_expr id="37" call_sroutine_arg="RETURN_VALUE" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,declare_db_conn,conn_cx]" />
+				</routine_stmt>
+			</routine>
+			<routine id="38" si_name="open_db_conn" routine_type="PROCEDURE">
+				<routine_context id="39" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_arg id="40" si_name="login_name" cont_type="SCALAR" scalar_data_type="[,root,elements,loginauth]" />
+				<routine_arg id="41" si_name="login_pass" cont_type="SCALAR" scalar_data_type="[,root,elements,loginauth]" />
+				<routine_stmt id="42" call_sroutine="CATALOG_OPEN">
+					<routine_expr id="43" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,open_db_conn,conn_cx]" />
+					<routine_expr id="44" call_sroutine_arg="LOGIN_NAME" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,open_db_conn,login_name]" />
+					<routine_expr id="45" call_sroutine_arg="LOGIN_PASS" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,open_db_conn,login_pass]" />
+				</routine_stmt>
+			</routine>
+			<routine id="46" si_name="close_db_conn" routine_type="PROCEDURE">
+				<routine_context id="47" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_stmt id="48" call_sroutine="CATALOG_CLOSE">
+					<routine_expr id="49" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,close_db_conn,conn_cx]" />
+				</routine_stmt>
+			</routine>
+			<routine id="50" si_name="fetch_all_persons" routine_type="FUNCTION" return_cont_type="RW_ARY" return_row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]">
+				<routine_context id="51" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_var id="52" si_name="person_ary" cont_type="RW_ARY" row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]" />
+				<view id="53" si_name="fetch_all_persons" view_type="ALIAS" row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]" set_p_routine_item="[,root,blueprints,People Watcher,fetch_all_persons,person_ary]">
+					<view_src id="54" si_name="person" match="[,root,blueprints,The Catalog Blueprint,gene,person]" />
+				</view>
+				<routine_stmt id="55" call_sroutine="SELECT">
+					<routine_expr id="56" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,fetch_all_persons,conn_cx]" />
+					<routine_expr id="57" call_sroutine_arg="SELECT_DEFN" cont_type="SRT_NODE" act_on="[,root,blueprints,People Watcher,fetch_all_persons,fetch_all_persons]" />
+				</routine_stmt>
+				<routine_stmt id="58" call_sroutine="RETURN">
+					<routine_expr id="59" call_sroutine_arg="RETURN_VALUE" cont_type="RW_ARY" valf_p_routine_item="[,root,blueprints,People Watcher,fetch_all_persons,person_ary]" />
+				</routine_stmt>
+			</routine>
+			<routine id="60" si_name="insert_a_person" routine_type="PROCEDURE">
+				<routine_context id="61" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_arg id="62" si_name="person" cont_type="ROW" row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]" />
+				<view id="63" si_name="insert_a_person" view_type="INSERT" row_data_type="[,root,blueprints,The Catalog Blueprint,gene,person_type]" ins_p_routine_item="[,root,blueprints,People Watcher,insert_a_person,person]">
+					<view_src id="64" si_name="person" match="[,root,blueprints,The Catalog Blueprint,gene,person]" />
+				</view>
+				<routine_stmt id="65" call_sroutine="INSERT">
+					<routine_expr id="66" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,insert_a_person,conn_cx]" />
+					<routine_expr id="67" call_sroutine_arg="INSERT_DEFN" cont_type="SRT_NODE" act_on="[,root,blueprints,People Watcher,insert_a_person,insert_a_person]" />
+				</routine_stmt>
+			</routine>
+			<routine id="68" si_name="update_a_person" routine_type="PROCEDURE">
+				<routine_context id="69" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_arg id="70" si_name="arg_person_id" cont_type="SCALAR" scalar_data_type="[,root,elements,entity_id]" />
+				<routine_arg id="71" si_name="arg_person_name" cont_type="SCALAR" scalar_data_type="[,root,elements,person_name]" />
+				<routine_arg id="72" si_name="arg_father_id" cont_type="SCALAR" scalar_data_type="[,root,elements,entity_id]" />
+				<routine_arg id="73" si_name="arg_mother_id" cont_type="SCALAR" scalar_data_type="[,root,elements,entity_id]" />
+				<view id="74" si_name="update_a_person" view_type="UPDATE">
+					<view_src id="75" si_name="person" match="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<view_src_field id="76" si_match_field="[,root,elements,person,person_id]" />
+						<view_src_field id="77" si_match_field="[,root,elements,person,name]" />
+						<view_src_field id="78" si_match_field="[,root,elements,person,father_id]" />
+						<view_src_field id="79" si_match_field="[,root,elements,person,mother_id]" />
+					</view_src>
+					<view_expr id="80" view_part="SET" set_src_field="[,root,blueprints,People Watcher,update_a_person,update_a_person,person,name]" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,update_a_person,arg_person_name]" />
+					<view_expr id="81" view_part="SET" set_src_field="[,root,blueprints,People Watcher,update_a_person,update_a_person,person,father_id]" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,update_a_person,arg_father_id]" />
+					<view_expr id="82" view_part="SET" set_src_field="[,root,blueprints,People Watcher,update_a_person,update_a_person,person,mother_id]" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,update_a_person,arg_mother_id]" />
+					<view_expr id="83" view_part="WHERE" cont_type="SCALAR" valf_call_sroutine="EQ">
+						<view_expr id="84" cont_type="SCALAR" valf_src_field="[,root,blueprints,People Watcher,update_a_person,update_a_person,person,person_id]" />
+						<view_expr id="85" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,update_a_person,arg_person_id]" />
+					</view_expr>
+				</view>
+				<routine_stmt id="86" call_sroutine="UPDATE">
+					<routine_expr id="87" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,update_a_person,conn_cx]" />
+					<routine_expr id="88" call_sroutine_arg="UPDATE_DEFN" cont_type="SRT_NODE" act_on="[,root,blueprints,People Watcher,update_a_person,update_a_person]" />
+				</routine_stmt>
+			</routine>
+			<routine id="89" si_name="delete_a_person" routine_type="PROCEDURE">
+				<routine_context id="90" si_name="conn_cx" cont_type="CONN" conn_link="[,root,blueprints,People Watcher,editor_link]" />
+				<routine_arg id="91" si_name="arg_person_id" cont_type="SCALAR" scalar_data_type="[,root,elements,entity_id]" />
+				<view id="92" si_name="delete_a_person" view_type="DELETE">
+					<view_src id="93" si_name="person" match="[,root,blueprints,The Catalog Blueprint,gene,person]">
+						<view_src_field id="94" si_match_field="[,root,elements,person,person_id]" />
+					</view_src>
+					<view_expr id="95" view_part="WHERE" cont_type="SCALAR" valf_call_sroutine="EQ">
+						<view_expr id="96" cont_type="SCALAR" valf_src_field="[,root,blueprints,People Watcher,delete_a_person,delete_a_person,person,person_id]" />
+						<view_expr id="97" cont_type="SCALAR" valf_p_routine_item="[,root,blueprints,People Watcher,delete_a_person,arg_person_id]" />
+					</view_expr>
+				</view>
+				<routine_stmt id="98" call_sroutine="DELETE">
+					<routine_expr id="99" call_sroutine_cxt="CONN_CX" cont_type="CONN" valf_p_routine_item="[,root,blueprints,People Watcher,delete_a_person,conn_cx]" />
+					<routine_expr id="100" call_sroutine_arg="DELETE_DEFN" cont_type="SRT_NODE" act_on="[,root,blueprints,People Watcher,delete_a_person,delete_a_person]" />
+				</routine_stmt>
+			</routine>
+		</application>
+	</blueprints>
+	<tools>
+		<data_storage_product id="101" si_name="SQLite v2.8.12" product_code="SQLite_2_8_12" is_file_based="1" />
+		<data_storage_product id="102" si_name="Oracle v9i" product_code="Oracle_9_i" is_network_svc="1" />
+		<data_link_product id="103" si_name="Microsoft ODBC" product_code="ODBC" />
+	</tools>
+	<sites>
+		<catalog_instance id="104" si_name="test" blueprint="[,root,blueprints,The Catalog Blueprint]" product="[,root,tools,101]">
+			<user id="105" si_name="ronsealy" user_type="SCHEMA_OWNER" match_owner="[,root,blueprints,The Catalog Blueprint,Gene\'s Owner]" password="K34dsD" />
+			<user id="106" si_name="joesmith" user_type="DATA_EDITOR" password="fdsKJ4" />
+		</catalog_instance>
+		<application_instance id="107" si_name="test Setup" blueprint="[,root,blueprints,Setup]">
+			<catalog_link_instance id="108" blueprint="[,root,blueprints,Setup,admin_link]" product="[,root,tools,103]" target="[,root,sites,test]" local_dsn="test" />
+		</application_instance>
+		<application_instance id="109" si_name="test People Watcher" blueprint="[,root,blueprints,People Watcher]">
+			<catalog_link_instance id="110" blueprint="[,root,blueprints,People Watcher,editor_link]" product="[,root,tools,103]" target="[,root,sites,test]" local_dsn="test" />
+		</application_instance>
+		<catalog_instance id="111" si_name="demo" blueprint="[,root,blueprints,The Catalog Blueprint]" product="[,root,tools,102]">
+			<user id="112" si_name="florence" user_type="SCHEMA_OWNER" match_owner="[,root,blueprints,The Catalog Blueprint,Gene\'s Owner]" password="0sfs8G" />
+			<user id="113" si_name="thainuff" user_type="DATA_EDITOR" password="9340sd" />
+		</catalog_instance>
+		<application_instance id="114" si_name="demo Setup" blueprint="[,root,blueprints,Setup]">
+			<catalog_link_instance id="115" blueprint="[,root,blueprints,Setup,admin_link]" product="[,root,tools,103]" target="[,root,sites,demo]" local_dsn="demo" />
+		</application_instance>
+		<application_instance id="116" si_name="demo People Watcher" blueprint="[,root,blueprints,People Watcher]">
+			<catalog_link_instance id="117" blueprint="[,root,blueprints,People Watcher,editor_link]" product="[,root,tools,103]" target="[,root,sites,demo]" local_dsn="demo" />
+		</application_instance>
+	</sites>
+	<circumventions />
+</root>
+'
+	);
+}
+
+######################################################################
+
 1;
